package com.dragonkode.testing;

/**<pre>=======================================================================
 * Represents the control logic of a unit test for a method that does have
 * parameters.
 * 
 * Usage:
 * > call test(ValueTestLogic) inside [MethodTest subclass].test()
 *   > where ValueTestLogic is the unit test logic for the method test
 * 
 * @see ClassTester
 * @see MethodTest
 * @see MultiValueTest
 * @see ValueTestLogic
 * @author J. Bradley Edwards | brad.edwards@dragonkode.com
 * @author DragonKode | dragonkode.com
 * @date June 21, 2013
 * @version 1.0
 * (c) 2013 DragonKode. This software is covered by the 
 * MIT license: http://opensource.org/licenses/MIT.
 *
 * Methods:
 * > test(ValueTestLogic): runs a valid values unit test and reports the result
 * > test(ValueTestLogic, ValueTestLogic): runs valid and invalid values unit
 *   tests and reports the result
 *
 * ====================================================================</pre>*/
public class NoValueTest {
	/* === METHODS === */
	/**<pre>
	 * Controls a unit test that does not require passing values to the tested
	 * method.
	 * 
	 * Logic:
	 * > Run unit test for tested method
	 *   > if test fails, report failure
	 *   > if test passes, report pass
	 *   
	 * @param valid unit test logic for valid values for a specific method
	 </pre>
	 */
	public static void test(ValueTestLogic valid) {
		boolean testFail = false;
		/* run valid values unit test */
		testFail = valid.test();
		/* If test fails, report failure. If test passes, report pass. */
		if (testFail) {
			System.out.print("FAIL\n");
		} else {
			System.out.print("OK\n");
		}
	}
}
