package com.dragonkode.testing;

/**<pre>=======================================================================
 * Represents the unit test logic for a single call to the tested method.
 * 
 * Usage:
 * > override test() or test(Object value)
 *   > call tested method and check result
 *   > if test passes, return false (testFail == false)
 *   > if test fails, return true (testFail == true)
 *
 * @see ClassTester
 * @see MethodTest
 * @see NoValueTest
 * @see MultiValueTest
 * @author J. Bradley Edwards | brad.edwards@dragonkode.com
 * @author DragonKode | dragonkode.com
 * @date June 24, 2013
 * @version 1.1
 * (c) 2013 DragonKode. This software is covered by the 
 * MIT license: http://opensource.org/licenses/MIT.
 *
 * Methods:
 * > test(): runs a unit test that does not pass a value to the tested method
 * > test(Object): runs a unit test that passes a value to the tested method
 *
 * ====================================================================</pre>*/
public abstract class ValueTestLogic {
	/* === METHODS === */
	/**<pre>
	 * Runs a unit test that does not pass a value to the tested method.
	 * 
	 * Logic:
	 * > Execute a method-level unit test
	 * > return true if test FAILS, return false if test PASSES
	 * 
	 * @return true if test fails, false if test passes
	 </pre>*/
	public boolean test() {
		return false;
	}

	/**<pre>
	 * Runs a unit test that passes a value to the tested method.
	 * 
	 * Logic:
	 * > Execute a method-level unit test using value of the parameter
	 * > return true if test FAILS, return false if test PASSES
	 * 
	 * @param value value to pass to tested method
	 * @return true if test fails, false if test passes
	 </pre>*/
	public boolean test(Object value) {
		return false;
	}
}